@@ -35,12 +35,12 @@
 
   ID:                 juce_audio_processors
   vendor:             juce
-  version:            7.0.2
+  version:            7.0.6
   name:               JUCE audio processor classes
   description:        Classes for loading and playing VST, AU, LADSPA, or internally-generated audio processors.
   website:            http://www.juce.com/juce
   license:            GPL/Commercial
-  minimumCppStandard: 14
+  minimumCppStandard: 17
 
   dependencies:       juce_gui_extra, juce_audio_basics
   OSXFrameworks:      CoreAudio CoreMIDI AudioToolbox
@@ -130,7 +130,8 @@
 #endif
 
 //==============================================================================
-#include "utilities/juce_VSTCallbackHandler.h"
+#include "utilities/juce_AAXClientExtensions.h"
+#include "utilities/juce_VST2ClientExtensions.h"
 #include "utilities/juce_VST3ClientExtensions.h"
 #include "utilities/juce_NativeScaleFactorNotifier.h"
 #include "format_types/juce_ARACommon.h"
